// protoparser.js, copyright (c) 2018 Alexey Galkin <https://gitlab.com/johnbrown90210/protoparser.js> and 2019-2020 Nikita Tseykovets <tseikovets@rambler.ru>, licensed under the MIT license.
// version 6(145)
const PARTICIPLE_SUFFIX={m:'',f:'а',n:'о',p:'ы'}
const GEND_SUFFIX={m:/[^аьяоеыи]/,f:/[аья]/,n:/[ое]/,p:/[ыи]/}
var visitedLocs={}
var gameCommands={examine:['examine',['осмотреться','осмотреть','изучить','смотреть','см','исследовать','рассмотреть','о','осм'],-1],north:['walk',['север','с'],0,'n'],south:['walk',['юг','ю'],0,'s'],west:['walk',['запад','з'],0,'w'],east:['walk',['восток','в'],0,'e'],up:['walk',['вверх','вв','наверх'],0,'u'],down:['walk',['вниз','вн'],0,'d'],northEast:['walk',['северо-восток','с-в','св'],0,'ne'],northWest:['walk',['северо-запад','с-з','сз'],0,'nw'],southEast:['walk',['юго-восток','ю-в','юв'],0,'se'],southWest:['walk',['юго-запад','ю-з','юз'],0,'sw'],inventory:['inventory',['инвентарь','инв','и'],0],take:['take',['взять','поднять','забрать','подобрать'],1],drop:['drop',['бросить','выбросить','положить','оставить','выкинуть'],1],wait:['wait',['ждать','подождать'],0],read:['read',['читать','прочитать'],1],eat:['eat',['съесть','есть','кушать','скушать'],1],wear:['wear',['надеть'],1],disrobe:['disrobe',['снять'],1],open:['open',['открыть'],1],close:['close',['закрыть'],1],unlock:['unlock',['отпереть'],1],lock:['lock',['запереть'],1],jump:['jump',['прыгать','прыгнуть','подпрыгнуть'],0],attack:['attack',['ударить','пнуть','стукнуть','атаковать'],1],sleep:['sleep',['спать','поспать','заснуть'],0],say:['say',['сказать','произнести','ответить','спросить','говорить'],2,'noun'],listen:['listen',['слушать','подслушать','послушать'],-1],smell:['smell',['нюхать','понюхать'],-1],sing:['sing',['петь','спеть','запеть'],0],show:['show',['показать','продемонстрировать','демонстрировать'],1],buy:['buy',['купить','приобрести'],1],sell:['sell',['продать','сбыть'],1],screw:['screw',['завинтить','закрутить','вкрутить','ввинтить','прикрутить'],1],unscrew:['unscrew',['открутить','выкрутить','вывинтить'],1],think:['think',['думать','подумать','размышлять','задуматься'],0],wake:['wake',['проснуться','пробудиться'],0],jumpOver:['jumpOver',['перепрыгнуть'],1],kiss:['kiss',['поцеловать','целовать','расцеловать'],1],rub:['rub',['тереть','протереть','натереть','начистить','потереть'],1],cut:['cut',['резать','разрезать','перерезать','отрезать','срезать','обрезать','пилить','отпилить','перепилить','рубить','срубить','отрубить','отсечь'],1],tie:['tie',['привязать','завязать','связать'],1],untie:['untie',['развязать','отвязать'],1],burn:['burn',['зажечь','поджечь','сжечь','жечь'],1],bow:['bow',['поклониться','кланяться'],-1],clear:['clear',['очистить'],0,'sysCom'],score:['score',['счет','счёт','сч','очки','ход','ходы'],0,'sysCom'],restart:['restart',['заново','сначала'],0,'sysCom'],about:['about',['версия'],0,'sysCom'],saveGame:['saveGame',['сохранить'],2,'sysCom'],loadGame:['loadGame',['загрузить','восстановить'],2,'sysCom'],advice:['advice',['совет','подсказка','спойлер'],0,'sysCom'],help:['help',['помощь','справка','?'],0,'sysCom'],history:['history',['история'],0,'sysCom'],repeat:['repeat',['п','повтор','повторить'],0,'sysCom'],log:['log',['лог','транскрипт'],0,'sysCom'],places:['places',['места','локации','комнаты'],0,'sysCom']}
var defSysVal={longCommandMsg:'Команда должна состоять не более чем из двух слов.',emptyCommandMsg:'Простите?',unknownCommandMsg:'Команда непонятна.',noScoreMsg:'В этой игре не ведется счет.',overburdenMsg:'Вы несете слишком много вещей.',confirmRestartMsg:'Вы действительно хотите начать игру заново?',cancelRestartMsg:'Команда отменена.',savedMsg:'Игра сохранена.',notSavedMsg:'Ошибка сохранения.',loadedMsg:'Игра загружена.',notLoadedMsg:'Ошибка загрузки.',noThingMsg:'Здесь нет этого предмета.',winMsg:'<p style="font-weight: bold; text-align: center;">*** Вы победили! ***</p>',lostMsg:'<p style="font-weight: bold; text-align: center;">*** Вы проиграли! ***</p>',saveForbiddenMsg:'В этой игре сохранение запрещено.',loadForbiddenMsg:'В этой игре восстановление запрещено.',noWayMsg:'В этом направлении нельзя пойти.',placedHereMsg:' Здесь есть: ',playerHasNothingMsg:'У вас с собой ничего нет.',playerHasMsg:'У вас с собой: ',commandHistoryIsEmptyMsg:'История команд пуста.',commandHistoryOffMsg:'В этой игре не ведется история команд.',advice:'В этой игре не предусмотрено подсказок.',help:'Для ввода команд используйте шаблон ГЛАГОЛ [СУЩЕСТВИТЕЛЬНОЕ]. Регистр и лишние пробелы не учитываются. Команда должна состоять не более чем из двух слов. Полный список стандартных команд, поддерживаемых протопарсером, указан в Руководстве автора, в <a href="https://gitlab.com/johnbrown90210/protoparser.js/blob/master/manual/protoparser_manual.md#%D0%BF%D1%80%D0%B8%D0%BB%D0%BE%D0%B6%D0%B5%D0%BD%D0%B8%D0%B5-1" target="_blank" style="color: brown">Приложении 1</a>.<br><br><b>Системные команды:</b><br><ul><li><em>Сохранить &#91имя&#93</em> – сохраняет текущее состояние игры под заданным именем;</li><li><em>Загрузить &#91имя&#93</em> – загружает сохраненное состояние игры с заданным именем;</li><li><em>Заново</em> – перезапускает игру;</li><li><em>Повторить (Numpad +)</em> – выполняет последнюю команду, сохраненную в истории команд;</li><li><em>История (F6)</em> – выводит список команд, сохраненных в истории команд;</li><li><em>Счет (Numpad *)</em> – выводит текущий счет и количество сделанных ходов с начала игры;</li><li><em>Версия (F2)</em> – выводит информацию о версии protoparser.js и лицензиях;</li><li><em>Очистить</em> – удаляет с экрана лог игры;</li><li><em>Совет (F7)</em> – выводит советы по игре (если автор их написал);</li><li><em>Стрелка вверх</em> – добавляет команду из истории команд в строку ввода: от последней к более ранним;</li><li><em>Стрелка вниз</em> – добавляет команду из истории команд в строку ввода: от самой первой к более поздним;</li><li><em>Лог (F8)</em> – выводит доступный для копирования лог игры в отдельном окне браузера;</li><li><em>Локации (F9)</em> – выводит список посещенных локаций и находившихся в них объектов, которые были осмотрены;</li><li><em>Справка (F1)</em> – выводит краткую справочную информацию по управлению игрой.</li></ul>',think:'Вы все время думаете.',wake:'Это не сон.',kiss:'Вы сдерживаете свой порыв.',noVisitedMsg:'Вы пока не посетили ни одной локации.',wait:'Проходит немного времени.',jump:'Вы подпрыгиваете.',sleep:'Сейчас не время для сна.',listen:'Вы не слышите ничего необычного.',smell:'Вы не чувствуете ничего необычного.',sing:'Вы запеваете подходящую случаю песню.',points:0,turn:0,cursor:'|',commandTemplate:'',prompt:'> ',fireCursorInterval:500,shouldBlinkCursor:true,commandHistoryLength:10,commandHistoryIndex:-1,logRecord:'',num7Key:'северо-запад',num8Key:'север',num9Key:'северо-восток',num4Key:'запад',num5Key:'осмотреться',num6Key:'восток',num1Key:'юго-запад',num2Key:'юг',num3Key:'юго-восток',num0Key:'вниз',decimalPointKey:'вверх',devideKey:'инвентарь',multiplyKey:'счет',addKey:'повторить',f1Key:'помощь',f2Key:'версия',f6Key:'история',f7Key:'совет',f8Key:'лог',f9Key:'локации'}
for(property in defSysVal)
if(!game.hasOwnProperty(property))game[property]=defSysVal[property]
var t=new Terminal('term');t.setHeight("1200px");t.setWidth('600px');document.body.appendChild(t.html);init();function inp(){t.input('<br>',function(input){output(input);(!game.stopped)&&inp();});}
function parser(input){input=input.toLowerCase().slice(game.prompt.length);var words=input.trim().replace(/[^0-9a-zа-яё ]/g, '').split(/\s+/);
	if(words.length > 2) {
		for(var i in game.ignoredPrepositions) {
			var prep = words.indexOf(game.ignoredPrepositions[i])
			if(prep >= 0)
				words.splice(prep, 1)
		}
	}
if(words.length>2)return t.print(game.longCommandMsg)
if(words=='')return t.print(game.emptyCommandMsg)
var verb=words[0];var noun=words[1];for(var com in gameCommands)
if(gameCommands[com][1].indexOf(verb)!=-1)return choiceHandler(gameCommands[com][0],gameCommands[com][2],noun,verb,gameCommands[com][3]=='noun'?noun:gameCommands[com][3]=='verb'?verb:gameCommands[com][3])
t.print(game.unknownCommandMsg)}
function output(input){parser(input);}
// modified by Nikita Tseykovets
/*
function examine(obj){var roomDesc;if(obj===undefined){var objInRoom=getObjByKV('loc',player.loc);var objWithSceneDesc=objInRoom.filter(function(obj){return obj.sceneDesc&&!obj.hidden})
var nonHiddenObj=objInRoom.filter(function(obj){return!obj.hidden&&!obj.sceneDesc})
var objDesc=''
for(var i in objWithSceneDesc)
objDesc+=' '+objWithSceneDesc[i].sceneDesc
var objNames='<br><br>'+game.placedHereMsg;for(var i in nonHiddenObj){objNames+=nonHiddenObj[i].nam[0];(i<nonHiddenObj.length-1)?objNames+=', ':objNames+='.'}
if(nonHiddenObj.length==0)objNames=''
t.print(window[player.loc].desc+objDesc+objNames)}else{(!obj.examined)?obj.examined=1:obj.examined++
t.print(obj.desc)}}
*/
function examine (obj) {
	var roomDesc;
	if(obj === undefined) {
		var objInRoom = getObjByKV('loc', player.loc);
		var objWithSceneDesc = objInRoom.filter(function(obj) {
			return obj.sceneDesc && !obj.hidden
		})
		var nonHiddenObj = objInRoom.filter(function(obj) {
			return !obj.hidden && !obj.sceneDesc
		})
		var objDesc = ''
		for(var i in objWithSceneDesc)
			objDesc += ' '+objWithSceneDesc[i].sceneDesc
		var objNames = '<br>'+game.placedHereMsg;
		for(var i in nonHiddenObj) {
			objNames += nonHiddenObj[i].nam[0];
			//(i < nonHiddenObj.length - 1) ? objNames += ', ' : objNames += '.'
			if(i == nonHiddenObj.length - 2) objNames += ' и '
			else if(i < nonHiddenObj.length - 1) objNames += ', '
			else objNames += '.'
		}
		if(nonHiddenObj.length == 0)
			objNames = ''
		t.print(window[player.loc].desc+objDesc+objNames)
	} else {
		(!obj.examined) ? obj.examined = 1 : obj.examined++
		t.print(obj.desc)
	}
}
function inventory(){var inv=getObjByKV('loc','player');inv=inv.filter(function(item){return!item.hiddenPossession})
if(inv.length==0){t.print(game.playerHasNothingMsg)}else{var invObj=game.playerHasMsg;for(var i=0;i<inv.length;i++){invObj+=inv[i].nam[0];if(inv[i].worn)invObj+=' (надет'+PARTICIPLE_SUFFIX[inv[i].gend]+')';(i<inv.length-1)?invObj+=', ':invObj+='.'}
t.print(invObj)}}
function take(obj){if(obj.takeable){if(obj.loc.indexOf('player')==-1){move(obj,'player')&&t.print('Вы забираете '+obj.nam[3]+'.')}else{t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' уже у вас.')}}else{t.print('Вы не можете взять '+obj.nam[3]+'.')}}
function drop(obj){if(obj.loc.indexOf(player.loc)==-1){if(obj.loc=='player'){if(obj.worn)disrobe(obj)
move(obj,player.loc);t.print('Вы оставляете здесь '+obj.nam[3]+'.')}}else{t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' уже здесь.')}}
function walk(obj,direction){if(direction in window[player.loc]){var pattern=new RegExp('(?=.*'+player.loc+')'+'(?=.*'+window[player.loc][direction]+')')
var door=getObjByKV('door',true).filter(function(o){if(pattern.test(o.loc))return true})
if(door[0]&&door[0].closed)return t.print('Путь прегражден '+door[0].nam[4]+'.')
move(player,window[player.loc][direction]);}else{t.print(game.noWayMsg)}}
function read(obj){if(obj.text)t.print(obj.text)
else t.print('На '+obj.nam[5]+' ничего не написано.')}
function eat(obj){if(obj.edible){remove(obj);t.print('Вы съедаете '+obj.nam[3]+'.')}else t.print(obj.nam[3][0].toUpperCase()+obj.nam[3].slice(1)+' нельзя употребить в пищу.')}
function wear(obj){if(obj.hasOwnProperty('worn')){if(!obj.worn){if(obj.loc!='player')take(obj)
if(obj.loc=='player'){obj.worn=true;t.print('Вы надеваете '+obj.nam[3]+'.')}}else t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' уже надет'+PARTICIPLE_SUFFIX[obj.gend]+'.')}else t.print(obj.nam[3][0].toUpperCase()+obj.nam[3].slice(1)+' нельзя надеть.')}
function disrobe(obj){if(obj.worn){obj.worn=false;obj.loc='player';t.print('Вы снимаете '+obj.nam[3]+'.')}else t.print('На вас нет '+obj.nam[1]+'.')}
function open(obj){if(obj.hasOwnProperty('closed')){if(obj.closed){if(!obj.locked){obj.closed=false;t.print('Вы открываете '+obj.nam[3]+'.')}
else t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' заперт'+PARTICIPLE_SUFFIX[obj.gend]+'.')}else t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' уже открыт'+PARTICIPLE_SUFFIX[obj.gend]+'.')}else t.print(obj.nam[3][0].toUpperCase()+obj.nam[3].slice(1)+' невозможно открыть.')}
function close(obj){if(obj.hasOwnProperty('closed')){if(!obj.closed){obj.closed=true;t.print('Вы закрываете '+obj.nam[3]+'.')}else t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' уже закрыт'+PARTICIPLE_SUFFIX[obj.gend]+'.')}else t.print(obj.nam[3][0].toUpperCase()+obj.nam[3].slice(1)+' невозможно закрыть.')}
function unlock(obj){if(!obj.hasOwnProperty('locked'))t.print(obj.nam[3][0].toUpperCase()+obj.nam[3].slice(1)+' невозможно отпереть.')
else if(!obj.closed)t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' уже открыт'+PARTICIPLE_SUFFIX[obj.gend]+'.')
else{if(obj.locked){obj.locked=false;t.print('Вы отпираете '+obj.nam[3]+'.')}else
t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' не заперт'+PARTICIPLE_SUFFIX[obj.gend]+'.')}}
function lock(obj){if(!obj.hasOwnProperty('locked'))t.print(obj.nam[3][0].toUpperCase()+obj.nam[3].slice(1)+' невозможно запереть.')
else if(!obj.closed)t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' не закрыт'+PARTICIPLE_SUFFIX[obj.gend]+'.')
else{if(!obj.locked){obj.locked=true;t.print('Вы запираете '+obj.nam[3]+'.')}else
t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' уже заперт'+PARTICIPLE_SUFFIX[obj.gend]+'.')}}
function attack(obj,option,verb){t.print('Не стоит пытаться '+verb+' '+obj.nam[3]+'.')}
function say(obj,citation){t.print('Вы говорите: \«'+citation[0].toUpperCase()+citation.slice(1)+'\».')}
function show(obj){if(obj.loc=='player')
t.print('Вы показываете '+obj.nam[3]+'.')
else t.print('Вы показываете на '+obj.nam[3]+'.')}
function buy(obj,option,verb){t.print('Вы не можете '+verb+' '+obj.nam[3]+'.')}
function sell(obj,option,verb){t.print('Вы не можете '+verb+' '+obj.nam[3]+'.')}
function screw(obj,option,verb){t.print('Не стоит пытаться '+verb+' '+obj.nam[3]+'.')}
function unscrew(obj){t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' ни к чему не прикручен'+PARTICIPLE_SUFFIX[obj.gend]+'.')}
function jumpOver(obj,option,verb){t.print('Не стоит пытаться '+verb+' '+obj.nam[3]+'.')}
function rub(obj,option,verb){t.print('Не стоит пытаться '+verb+' '+obj.nam[3]+'.')}
function cut(obj,option,verb){t.print('Не стоит пытаться '+verb+' '+obj.nam[3]+'.')}
function tie(obj,option,verb){t.print('Не стоит пытаться '+verb+' '+obj.nam[3]+'.')}
function untie(obj){t.print(obj.nam[0][0].toUpperCase()+obj.nam[0].slice(1)+' ни к чему не привязан'+PARTICIPLE_SUFFIX[obj.gend]+'.')}
function burn(obj,option,verb){t.print('Не стоит пытаться '+verb+' '+obj.nam[3]+'.')}
function bow(obj){t.print('Вы кланяетесь'+(obj?' '+obj.nam[2]:'')+'.')}
function clear(){t.clear();}
function score(){if(game.noScore)t.print(game.noScoreMsg)
else if(!game.maxScore)t.print('К '+game.turn+' ходу ваш счет равен '+game.points+'.')
else t.print('К '+game.turn+' ходу ваш счет равен '+game.points+' из '+game.maxScore+'.')}
function move(obj,loc){if(loc=='player'&&obj.spec=='thing'){if(getObjByKV('loc','player').length==player.maxCarried){t.print(game.overburdenMsg);return false}}
obj.loc=loc
obj.moved?obj.moved++:obj.moved=1
if(obj===player&&window[loc].spec=='room'){(!window[loc].visits)?window[loc].visits=1:window[loc].visits++
window[loc].head&&t.print('<br><b>'+window[loc].head+'</b>')
examine()}
return true}
function restart(){game.stopped=true
t.confirm(game.confirmRestartMsg,function(confirmed){if(confirmed){if(!window.localStorage)location.replace('index.html')
if(load('initialState'))init()
else location.replace('index.html')}else{game.stopped=false
t.print(game.cancelRestartMsg)
inp()}})}
function saveGame(obj,optional,verb,fileName){if(!game.noSaveLoad)save(fileName)?t.print(game.savedMsg):t.print(game.notSavedMsg)
else t.print(game.saveForbiddenMsg)}
function loadGame(obj,optional,verb,fileName){if(!game.noSaveLoad)load(fileName)?t.print(game.loadedMsg):t.print(game.notLoadedMsg)
else t.print(game.loadForbiddenMsg)}
function about(){t.print('protoparser.js<br>Версия: 6(145)<br>protoparser.js is copyright (c) 2018 Alexey Galkin, released under the MIT license.<br>terminal.js is copyright (c) 2014 Erik Österberg, 2018 Alexey Galkin, released under the MIT license.<br>Актуальная версия protoparser.js, а также текст лицензии доступны на странице проекта <a href="https://johnbrown90210.gitlab.com/protoparser.js" style="color: brown;">https://johnbrown90210.gitlab.com/protoparser.js</a>.')}
function repeat(){if(game.commandHistory[0])
output(game.prompt+game.commandHistory[0])
else history()}
function history(){if(game.commandHistory[0]){for(var i=game.commandHistory.length-1;i>-1;i--)
p(game.commandHistory.length-i+'. '+game.commandHistory[i])}else{game.commandHistoryLength==0?p(game.commandHistoryOffMsg):p(game.commandHistoryIsEmptyMsg)}}
function log(){var logWindow=window.document.open('','log','width=500,height=800')
logWindow.document.body.innerHTML=game.logRecord
logWindow.document.title='Лог игры'+(game.title?' «'+game.title+'»':'')}
function places(){if(Object.keys(visitedLocs)!=''){var n=0
for(var loc in visitedLocs){t.print(++n+'. '+window[loc].head)
if(visitedLocs[loc]!='')t.print('Вы осмотрели: '+visitedLocs[loc].join(', ')+'.')}}else t.print(game.noVisitedMsg)}
function remove(obj){for(o in window){if(window[o]&&window[o].nam===obj.nam){window[o]=undefined;break}}}
function reward(scores){if(!game.noScore){if(typeof scores=='number'){scores>0&&t.print('Ваш счет увеличился на '+scores+'.')
scores<0&&t.print('Ваш счет уменьшился на '+scores+'.')
game.points+=scores
score()}}}
function save(fileName){if(window.localStorage){for(var objName in window){if(window[objName]&&window[objName].spec){localStorage.setItem(objName+'___'+fileName+'___'+game.title,JSON.stringify(window[objName]))}}
return true}}
function load(fileName){if(window.localStorage){var n=0;for(var locObj in localStorage){if(locObj.indexOf('___'+fileName+'___'+game.title)!==-1){var obj=JSON.parse(localStorage.getItem(locObj))
for(localProperty in obj){window[locObj.slice(0,locObj.indexOf('___'))][localProperty]=obj[localProperty]}
n++}}
if(n!=0)return true}}
function end(mode){mode==1&&t.print(game.winMsg)
mode==0&&t.print(game.lostMsg)
!game.noScore&&score()
game.stopped=true}
function p(message){t.print(message)}
function gendDef(){if(!this.gend){var lastChar=this.nam[0].slice(-1)
for(var prop in GEND_SUFFIX){if(GEND_SUFFIX[prop].test(lastChar))
{this.gend=prop
break}}}}
function getObjByKV(key,value){var objArray=[];for(var objName in window){if(window[objName]&&((window[objName][key]instanceof Array&&window[objName][key].join(' ').match(new RegExp(value,'i')))||(window[objName][key]==value)))objArray.push(window[objName])}
return objArray}
function isNounValid(noun){if((noun!==undefined&&getObjByKV('nam',noun).length>0)&&(getObjByKV('nam',noun)[0].loc.indexOf(player.loc)!=-1||getObjByKV('nam',noun)[0].loc.indexOf('player')!=-1))return true}
function choiceHandler(com,comMode,noun,verb,optional){if(comMode>0&&noun==undefined)return t.print('Что вы хотите '+verb+'?')
if(comMode==0&&noun!=undefined)return t.print('Понятна только команда \«'+verb+'\».')
var handled=false
if(isNounValid(noun))var obj=getObjByKV('nam',noun)[0];if(noun===undefined||isNounValid(noun)||comMode==2){optional!='sysCom'&&game.turn++
(game.commandHistory.indexOf(noun?verb+' '+noun:verb)==-1&&com!='repeat'&&com!='history')&&game.commandHistory.unshift(noun?verb+' '+noun:verb)
if(game.commandHistory.length>game.commandHistoryLength)game.commandHistory.pop()
if(window[player.loc].head)visitedLocs[player.loc]=getObjByKV('spec','thing').filter(function(thing){return thing.examined&&thing.loc.indexOf(player.loc)!=-1}).map(function(obj){return obj.nam[3]})
if(typeof events.beforeAll==='function')handled=events.beforeAll(com,obj,optional,verb,noun)
if(!handled){if(comMode!=2&&noun!==undefined&&com in getObjByKV('nam',noun)[0])handled=getObjByKV('nam',noun)[0][com](obj,optional,verb,noun);else if(com in window[player.loc])handled=window[player.loc][com](obj,optional,verb,noun)
else if(window.globalVerbs&&com in globalVerbs)handled=globalVerbs[com](obj,optional,verb,noun)
if(!handled)game[com]?t.print(game[com]):window[com](obj,optional,verb,noun)}
if(typeof events.afterAll==='function')events.afterAll(com,obj,optional,verb,noun);}else
t.print(game.noThingMsg)}
function init(){clear();game.title&&t.print('<span style="font-weight: bold;">'+game.title+'</span>');game.author&&t.print('Автор: '+game.author);game.version&&t.print('Версия: '+game.version);game.year&&t.print('Год: '+game.year);game.license&&t.print('Лицензия: '+game.license);game.ageRating&&t.print('Возрастные ограничения: '+game.ageRating);game.ifid&&t.print('<!-- UUID://'+game.ifid+'// -->');game.info&&t.print('<br><span style="font-style: italic;">'+game.info+'</span>');t.print('<br>')
game.stopped=false
game.commandHistory=[]
player.spec='player'
game.spec='game'
if(!window.events)window['events']={}
if(!window.globalVerbs)window['globalVerbs']={}
events.spec='events'
globalVerbs.spec='globalVerbs'
var things=getObjByKV('spec','thing')
for(var i in things)
gendDef.call(things[i])
gendDef.call(player)
save('initialState')
document.getElementsByTagName('title')[0].textContent=game.title
if(typeof events.onIntro==='function')events.onIntro()
move(player,player.loc)
player.moved--
if(game.tests)tests();inp();}
function tests(){commands.forEach(function(command,i){t.print('<br>Тест # '+(i+1)+': '+game.prompt+command);output(game.prompt+command)})
t.print('<br> ТЕСТИРОВАНИЕ ЗАВЕРШЕНО.')}